<p align="center">
    <img src="https://raw.githubusercontent.com/Dtar380/VideoService/main/assets/logo.png">
</p>
<br>

---

# :vhs: **VideoService**

## **The library you needed to create your own Video Service**
**VideoService** is a python library focused on the BackEnd for Video Services, such as YouTube (Note that this library is not used in YouTube, it is just an example). <br>
**VideoService** uses a JSON DataBase to manage all the Videos on the server and its not dependant on external libraries to work (except for OpenCV and Lingua), all functionalities depend on bare Python libraries.

## :bookmark_tabs: **Table of Content**
- [**Main features**](#blue_heart-main-features)
- [**Install package**](#arrow_down-install-package)
- [**Working On**](#memo-working-on)
- [**Known Issues**](#open_file_folder-known-issues)
- [**License**](#scroll-license)
- [**Sponsorship**](#money_with_wings-sponsorship)

---

## :blue_heart: Main Features
- **Playlists Management**
- **Videos Managements**
- **File management**
- **Easy endpoints access**

## :arrow_down: Install package

#### Make sure you running on Python 3.8 or above

### PIP
- #### **If you want user intended version, run:**`pip install VideoService`
- #### **If you want tester intended version, run:** `pip install VideoService[dev]`

### Cloning repository
1. **Clone this repository or download it**
2. **Put the VideoService folder on your project folder**
3. **You're good to go**

## :memo: Working On
Im currently documenting the project and solving all [known issues](#open_file_folder-known-issues)(0.2.0 following the convention of Mayor.Minor.Patch)

### Already planned releases
| VERSION | INCLUDES                          |
|---------|-----------------------------------|
|  0.3.0  | Include more safety measurements  |
|  0.4.0  | Function adaptability             |
|  0.5.0  | Include optimization              |
|  1.0.0  | First Release Version (refactor)  |

### On consideration
Right now we have three main things in consideration for future updates for this Application, which are:

- **Search Engine**: Including our own search engine
- **Query's**: Better query's for the videos and playlists

Feel free to open Feature Requests [issues](https://github.com/Dtar380/WorkspaceAutomation/issues/new/choose) to request things related to this concepts such popular IDE's, popular Git services with REST API's (API needed for being able to give support), unwanted types of files and folders generated by WorkSpace creations, etc.

## :open_file_folder: Known Issues
As there hasn't been a deploy yet, Im not trying to find bugs, Im just coding and testing

## :scroll: License
VideoService is distributed under the license MIT.<br>
See the [LICENSE](LICENSE) file for more information.

## :money_with_wings: Sponsorship
You can support me and the project with a donation to my Ko-Fi<br>

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/H2H4TBMEZ)
